@@ -142,6 +142,7 @@ void horizontalcall::doAction2()
 void horizontalcall::doAction3()
 {
     listWidgetFiltered->clear();
+    m_NameStrings.clear();
     deleteLetters();
     fetchContacts();
 }
@@ -404,6 +405,8 @@ int horizontalcall::top_application()
 {
     qDebug() << "Main Thread : Top Application Slot Called.";
     show();
+    this->activateWindow();
+    this->raise();
     return 0;
 }
 
@@ -689,11 +692,17 @@ void horizontalcall::Copy_m_Contacts(QList<QtMobility::QContact> i_Contacts)
     qDebug() << "Main Thread : Copied m_Contacts, size is : " << m_Contacts.size();
 }
 
+void horizontalcall::contactNameClicked()
+{
+    showContactDetails(m_CurrentRow);
+}
+
 void horizontalcall::showContactDetails(int row)
 {
     qDebug() << "Main Thread : Printing contact in row : " << row;
     pushButtonClear->setText("Back");
     deleteLetters();
+    m_CurrentRow = row;
 
     if (m_scrollArea != NULL) {
         m_scrollArea->close();
@@ -723,6 +732,8 @@ void horizontalcall::showContactDetails(int row)
     m_scrollArea->widget()->layout()->addWidget(aButton);
     aButton->show();
 
+    connect(aButton, SIGNAL(clicked()), this, SLOT(contactNameClicked()));
+
 
     QContact a = m_Contacts.at(row);
     qDebug("Main Thread : " + a.displayLabel().toAscii());
@@ -774,11 +785,13 @@ void horizontalcall::phoneNumberClicked()
     callNumberButton = new QPushButton(m_scrollArea->widget());
     sendSMSButton = new QPushButton(m_scrollArea->widget());
     callNumberButton->setText("Call");
-    callNumberButton->setStyleSheet(m_StylePhoneNumbers);
+    callNumberButton->setStyleSheet(m_StylePhoneNumbersShort);
     callNumberButton->sizePolicy().setVerticalPolicy(QSizePolicy::Expanding);
+    callNumberButton->setMaximumHeight(1000000);
     sendSMSButton->setText("SMS");
-    sendSMSButton->setStyleSheet(m_StylePhoneNumbers);
+    sendSMSButton->setStyleSheet(m_StylePhoneNumbersShort);
     sendSMSButton->sizePolicy().setVerticalPolicy(QSizePolicy::Expanding);
+    sendSMSButton->setMaximumHeight(1000000);
     m_scrollArea->widget()->layout()->addWidget(callNumberButton);
     m_scrollArea->widget()->layout()->addWidget(sendSMSButton);
 
@@ -786,30 +799,6 @@ void horizontalcall::phoneNumberClicked()
     connect(sendSMSButton, SIGNAL(clicked()),this, SLOT(sendSMS()));
 
     m_showingContactOptions = true;
-
-    /*if (msgBox.clickedButton() == callButton) {
-        qDebug() << "Main Thread : Call";
-        QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
-        m_CallButtons.append(tempButton);
-        QString temp = tempButton->text();
-        m_PhoneNumbers.append(new QString(tempButton->text()));
-        tempButton->setText("Dialing...");
-        QTimer::singleShot(1000, this, SLOT(enableButtons()));
-        tempButton->setEnabled(false);
-        makeDbusGSMCall(temp);
-        //sendFastSMS(temp);
-    } else if (msgBox.clickedButton() == smsButton) {
-        qDebug() << "Main Thread : SMS";
-        QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
-        m_CallButtons.append(tempButton);
-        QString temp = tempButton->text();
-        m_PhoneNumbers.append(new QString(tempButton->text()));
-        tempButton->setText("SMSing...");
-        QTimer::singleShot(1000, this, SLOT(enableButtons()));
-        tempButton->setEnabled(false);
-        //makeDbusGSMCall(temp);
-        sendFastSMS(temp);
-    }*/
 }
 
 void horizontalcall::sendSMS()
@@ -819,7 +808,7 @@ void horizontalcall::sendSMS()
     QString temp = sendSMSButton->text();
     m_PhoneNumbers.append(new QString("SMS"));
     sendSMSButton->setText("Sending sms...");
-    QTimer::singleShot(500, this, SLOT(enableButtons()));
+    QTimer::singleShot(2000, this, SLOT(enableButtons()));
     sendSMSButton->setEnabled(false);
     sendFastSMS(m_Phonenumber);
 }
@@ -831,7 +820,7 @@ void horizontalcall::callNumber()
     QString temp = callNumberButton->text();
     m_PhoneNumbers.append(new QString("Call"));
     callNumberButton->setText("Dialing...");
-    QTimer::singleShot(500, this, SLOT(enableButtons()));
+    QTimer::singleShot(2000, this, SLOT(enableButtons()));
     callNumberButton->setEnabled(false);
     makeDbusGSMCall(m_Phonenumber);
 }
